@@ -147,51 +147,62 @@ sub gnFR_finish {
       $logdir = $gnInitCfg{'Main'}{'LogFolder'} . "\/2ch\/";
       
       
+      my $str = "";
       my $logdir_1 = Encode::encode(&env_locale_to_encstr($ENV{'LANG'}), $logdir);
       if (!(-d $logdir_1)) {
-             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
-             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
-                                                           'GTK_DIALOG_MODAL',
-                                                           'GTK_MESSAGE_INFO',
-                                                           'GTK_BUTTONS_YES_NO',
-                                                           "2chディレクトリがありません。\n作成しますか？",
-                                                           ,
-                                                           'GTK_BUTTONS_YES' => 'gtk-yes',
-                                                           'GTK_BUTTONS_NO' => 'gtk-no');
-             if($gnMsgDialog->run eq 'yes') {
-                $gnMsgDialog->destroy;
-                undef($gnMsgDialog);
+#             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
+#             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
+#                                                           'GTK_DIALOG_MODAL',
+#                                                           'GTK_MESSAGE_INFO',
+#                                                           'GTK_BUTTONS_YES_NO',
+#                                                           "2chディレクトリがありません。\n作成しますか？",
+#                                                           ,
+#                                                           'GTK_BUTTONS_YES' => 'gtk-yes',
+#                                                           'GTK_BUTTONS_NO' => 'gtk-no');
+#             if($gnMsgDialog->run eq 'yes') {
+#                $gnMsgDialog->destroy;
+#                undef($gnMsgDialog);
                 mkdir($logdir_1);
-             }else{
-                $gnMsgDialog->destroy;
-                undef($gnMsgDialog);
-                exit(1);
-             }
+                $str = "\[ログ保存用フォルダ\]\n  $logdir_1\n";
+#             }else{
+#                $gnMsgDialog->destroy;
+#                undef($gnMsgDialog);
+#                exit(1);
+#             }
          
       }
 
       # <設定ディレクトリ>/.gnviewconfigへ書き込み
       if (!(-d $gnCfgPath)) {
-             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
-             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
-                                                           'GTK_DIALOG_MODAL',
-                                                           'GTK_MESSAGE_INFO',
-                                                           'GTK_BUTTONS_YES_NO',
-                                                           "設定ファイルを格納するディレクトリがありません。\n作成しますか？",
-                                                           ,
-                                                           'GTK_BUTTONS_YES' => 'gtk-yes',
-                                                           'GTK_BUTTONS_NO' => 'gtk-no');
-             if($gnMsgDialog->run eq 'yes') {
-                $gnMsgDialog->destroy;
-                undef($gnMsgDialog);
+#             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
+#             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
+#                                                           'GTK_DIALOG_MODAL',
+#                                                           'GTK_MESSAGE_INFO',
+#                                                           'GTK_BUTTONS_YES_NO',
+#                                                           "設定ファイルを格納するディレクトリがありません。\n作成しますか？",
+#                                                           ,
+#                                                           'GTK_BUTTONS_YES' => 'gtk-yes',
+#                                                           'GTK_BUTTONS_NO' => 'gtk-no');
+#             if($gnMsgDialog->run eq 'yes') {
+#                $gnMsgDialog->destroy;
+#                undef($gnMsgDialog);
                 mkdir($gnCfgPath);
-             }else{
-                $gnMsgDialog->destroy;
-                undef($gnMsgDialog);
-                exit(1);
-             }
+                $str .= "\[設定保存用フォルダ\]\n  $gnCfgPath\n";
+#             }else{
+#                $gnMsgDialog->destroy;
+#                undef($gnMsgDialog);
+#                exit(1);
+#             }
          
       }
+      
+      # キャッシュフォルダの初期化
+      $main::tmpdir = $gnCfgPath . "cache";
+      if(!(-d $main::tmpdir)) {
+         mkdir($main::tmpdir);
+         $str .= "\[キャッシュ保存用フォルダ\]\n  $main::tmpdir\n";
+      }
+      
       # 画像キャッシュテーブルの初期化
       $gnInitCfg{'Main'}{'cachetbl.ini'} = $gnCfgPath . "cachetbl.ini";
       if (!(-e $gnInitCfg{'Main'}{'cachetbl.ini'})) {
@@ -199,6 +210,22 @@ sub gnFR_finish {
          close(gnCTBL);
       }
       
+      # フォルダ作成通知
+      if($str ne "") {
+             $str = "以下のフォルダを作成しました\n\n" . $str;
+             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
+             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
+                                                           'GTK_DIALOG_MODAL',
+                                                           'GTK_MESSAGE_INFO',
+                                                           'GTK_BUTTONS_OK',
+                                                           $str,
+                                                           ,
+                                                           'GTK_BUTTONS_OK' => 'gtk-ok');
+             if($gnMsgDialog->run eq 'ok') {
+                $gnMsgDialog->destroy;
+             }
+      }
+      
       my $gnInitCfgFN = $gnCfgPath . ".gnviewconfig";
       $gnInitCfg{'Main'}{'gnCfgPath'} = $gnCfgPath;
       if($gnDebugFlag) { print Dumper(%gnInitCfg); }
@@ -214,25 +241,27 @@ sub gnFR_finish {
       #####################################################################
       
       # <設定ディレクトリ>を作成
+      my $str = "";
       if (!(-d $gnCfgPath)) {
-             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
-             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
-                                                           'GTK_DIALOG_MODAL',
-                                                           'GTK_MESSAGE_INFO',
-                                                           'GTK_BUTTONS_YES_NO',
-                                                           "設定ファイルを格納するディレクトリがありません。\n作成しますか？",
-                                                           ,
-                                                           'GTK_BUTTONS_YES' => 'gtk-yes',
-                                                           'GTK_BUTTONS_NO' => 'gtk-no');
-             if($gnMsgDialog->run eq 'yes') {
-                $gnMsgDialog->destroy;
-                undef($gnMsgDialog);
+#             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
+#             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
+#                                                           'GTK_DIALOG_MODAL',
+#                                                           'GTK_MESSAGE_INFO',
+#                                                           'GTK_BUTTONS_YES_NO',
+#                                                           "設定ファイルを格納するディレクトリがありません。\n作成しますか？",
+#                                                           ,
+#                                                           'GTK_BUTTONS_YES' => 'gtk-yes',
+#                                                           'GTK_BUTTONS_NO' => 'gtk-no');
+#             if($gnMsgDialog->run eq 'yes') {
+#                $gnMsgDialog->destroy;
+#                undef($gnMsgDialog);
                 mkdir($gnCfgPath);
-             }else{
-                $gnMsgDialog->destroy;
-                undef($gnMsgDialog);
-                exit(1);
-             }
+                $str = "\[設定保存用フォルダ\]\n  $gnCfgPath\n";
+#             }else{
+#                $gnMsgDialog->destroy;
+#                undef($gnMsgDialog);
+#                exit(1);
+#             }
          
       }
       my $gngikoNaviIni_from = &gnGetLibPath . "gikoNavi.ini";
@@ -281,27 +310,35 @@ sub gnFR_finish {
       
       
       if (!(-d $logdir)) {
-             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
-             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
-                                                           'GTK_DIALOG_MODAL',
-                                                           'GTK_MESSAGE_INFO',
-                                                           'GTK_BUTTONS_YES_NO',
-                                                           "2chディレクトリがありません。\n作成しますか？",
-                                                           ,
-                                                           'GTK_BUTTONS_YES' => 'gtk-yes',
-                                                           'GTK_BUTTONS_NO' => 'gtk-no');
-             if($gnMsgDialog->run eq 'yes') {
-                $gnMsgDialog->destroy;
-                undef($gnMsgDialog);
+#             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
+#             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
+#                                                           'GTK_DIALOG_MODAL',
+#                                                           'GTK_MESSAGE_INFO',
+#                                                           'GTK_BUTTONS_YES_NO',
+#                                                           "2chディレクトリがありません。\n作成しますか？",
+#                                                           ,
+#                                                           'GTK_BUTTONS_YES' => 'gtk-yes',
+#                                                           'GTK_BUTTONS_NO' => 'gtk-no');
+#             if($gnMsgDialog->run eq 'yes') {
+#                $gnMsgDialog->destroy;
+#                undef($gnMsgDialog);
                 mkdir($logdir);
-             }else{
-                $gnMsgDialog->destroy;
-                undef($gnMsgDialog);
-                exit(1);
-             }
+                $str .= "\[ログ保存用フォルダ\]\n  $logdir\n";
+#             }else{
+#                $gnMsgDialog->destroy;
+#                undef($gnMsgDialog);
+#                exit(1);
+#             }
          
       }
 
+      # キャッシュフォルダの初期化
+      $main::tmpdir = $gnCfgPath . "cache";
+      if(!(-d $main::tmpdir)) {
+         mkdir($main::tmpdir);
+         $str .= "\[キャッシュ保存用フォルダ\]\n  $main::tmpdir\n";
+      }
+      
       # 画像キャッシュテーブルの初期化
       $gnInitCfg{'Main'}{'cachetbl.ini'} = $gnCfgPath . "cachetbl.ini";
       if (!(-e $gnInitCfg{'Main'}{'cachetbl.ini'})) {
@@ -309,6 +346,22 @@ sub gnFR_finish {
          close(gnCTBL);
       }
       
+      # フォルダ作成通知
+      if($str ne "") {
+             $str = "以下のフォルダを作成しました\n\n" . $str;
+             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
+             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
+                                                           'GTK_DIALOG_MODAL',
+                                                           'GTK_MESSAGE_INFO',
+                                                           'GTK_BUTTONS_OK',
+                                                           $str,
+                                                           ,
+                                                           'GTK_BUTTONS_OK' => 'gtk-ok');
+             if($gnMsgDialog->run eq 'ok') {
+                $gnMsgDialog->destroy;
+             }
+      }
+      
       my $gnInitCfgFN = $gnCfgPath . ".gnviewconfig";
       $gnInitCfg{'Main'}{'gnCfgPath'} = $gnCfgPath;
       if($gnDebugFlag) { print Dumper(%gnInitCfg); }
