@@ -15,13 +15,13 @@ use Data::Dumper;
 
 #=======================================================
 my $stepflg = 1;
-my @gnReqLibs = ("Compress::Zlib",	"Config",		"Data::Dumper",	"Encode",
-                         "Encode::Guess",	"File::Basename",	"File::Copy",		"File::Path",
-                         "Glib",		"Gtk2",		"Gtk2::GladeXML",	"Gtk2::Pango",
-                         "HTML::Entities",	"HTML::TokeParser","HTTP::Cookies",	"HTTP::Date",
-                         "LWP::MediaTypes",	"LWP::UserAgent",	"List::Util",		"POSIX",
-                         "Thread::Queue",	"Time::HiRes",	"Time::Local",		"URI::file",
-                         "threads",		"threads::shared",	"utf8");
+my @gnReqLibs = ("Compress::Zlib",	"Config",		"Data::Dumper",		"Encode",
+                   "Encode::Guess",	"File::Basename",	"File::Copy",		"File::Path",
+                   "Glib",		"Gtk2",			"Gtk2::GladeXML",	"Gtk2::Pango",
+                   "HTML::Entities",	"HTML::TokeParser",	"HTTP::Cookies",	"HTTP::Date",
+                   "LWP::MediaTypes",	"LWP::UserAgent",	"List::Util",		"POSIX",
+                   "Storable",		"Thread::Queue",	"Time::HiRes",		"Time::Local",
+                   "URI::file",		"threads",		"threads::shared",	"utf8");
 my $gnUserLang;
 my $gnPerlpath;
 my $binpath = &gnGetBinPath;
